@@ -1,8 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# flake8: noqa
-
-from __future__ import unicode_literals
+#
 
 from django.db import migrations, models
 from django.conf import settings
@@ -22,7 +19,7 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('timezone', models.CharField(default='', max_length=100, choices=TIMEZONES)),
-                ('user', models.OneToOneField(related_name='mailman_profile', to=settings.AUTH_USER_MODEL)),
+                ('user', models.OneToOneField(related_name='mailman_profile', to=settings.AUTH_USER_MODEL, on_delete=models.CASCADE)),
             ],
         ),
     ]
